<?php

// Load Dolibase
include_once '../autoload.php';

// Load Dolibase SetupPage class
dolibase_include_once('/core/pages/setup.php');

// Load Dolibase QueryBuilder class
dolibase_include_once('/core/class/query_builder.php');

// Create Setup Page using Dolibase
$page = new SetupPage('AccessControl', '$user->admin', false, false);

// Get parameters
$action = GETPOST('action', 'alpha');
$id = GETPOST('id', 'int');
$rowid = GETPOST('rowid');

// Init vars
global $conf, $db;

$disallowed_users = array();

if (! empty($conf->global->SECURE_MY_DOLIBARR_DISALLOWED_USERS)) {
	$disallowed_users = explode(',', $conf->global->SECURE_MY_DOLIBARR_DISALLOWED_USERS);
}

// Set actions ---

// Allow User

if ($action == 'allow_user')
{
	if ($id > 0)
	{
		$changed = false;
		foreach ($disallowed_users as $key => $value)
		{
			if ($id == $value) {
				unset($disallowed_users[$key]);
				$changed = true;
			}
		}

		if ($changed) {
			dolibarr_set_const($db, 'SECURE_MY_DOLIBARR_DISALLOWED_USERS', join(',', $disallowed_users), 'chaine', 0, '', $conf->entity);
		}
	}
}

// Disallow User

else if ($action == 'disallow_user')
{
	if ($id > 0 && ! in_array($id, $disallowed_users))
	{
		$disallowed_users[] = $id;

		dolibarr_set_const($db, 'SECURE_MY_DOLIBARR_DISALLOWED_USERS', join(',', $disallowed_users), 'chaine', 0, '', $conf->entity);
	}
}

// Allow All

else if ($action == 'allow_all')
{
	if (is_array($rowid) && ! empty($rowid))
	{
		$changed = false;
		foreach ($disallowed_users as $key => $value)
		{
			if (in_array($value, $rowid)) {
				unset($disallowed_users[$key]);
				$changed = true;
			}
		}

		if ($changed) {
			dolibarr_set_const($db, 'SECURE_MY_DOLIBARR_DISALLOWED_USERS', join(',', $disallowed_users), 'chaine', 0, '', $conf->entity);
		}
	}
}

// Disallow All

else if ($action == 'disallow_all')
{
	if (is_array($rowid) && ! empty($rowid))
	{
		foreach ($rowid as $id)
		{
			if (! in_array($id, $disallowed_users)) {
				$disallowed_users[] = $id;
			}
		}

		dolibarr_set_const($db, 'SECURE_MY_DOLIBARR_DISALLOWED_USERS', join(',', $disallowed_users), 'chaine', 0, '', $conf->entity);
	}
}

// --- End actions

$page->addCssFile('common.css');

$page->addJsFile('access.js');

$page->addTab('Security', 'securemydolibarr/admin/security.php?mainmenu=home');

$page->addTab('AccessControl', 'securemydolibarr/admin/access.php?mainmenu=home', true);

$page->addTab('Audit', 'securemydolibarr/admin/audit.php?mainmenu=home');

$page->addTab('Backup', 'securemydolibarr/admin/backup.php?mainmenu=home');

$page->addTab('About', 'securemydolibarr/admin/about.php?mainmenu=home');

$page->begin();

$page->addSubtitle('UserAccess', 'user.png@securemydolibarr');

$page->showTemplate('access.php');

$page->end();
