<?php

// Load Dolibase
include_once '../autoload.php';

// Load Dolibase SetupPage class
dolibase_include_once('/core/pages/setup.php');

// Load Dolibase QueryBuilder class
dolibase_include_once('/core/class/query_builder.php');

// Load other requirements
require_once DOL_DOCUMENT_ROOT.'/core/lib/security2.lib.php';

// Create Setup Page using Dolibase
$page = new SetupPage('Security', '$user->admin', false, false);

// Get parameters
$action = GETPOST('action', 'alpha');
$confirm = GETPOST('confirm', 'alpha');

// Set actions ---

// Add install.lock

if ($action == 'add_install_lock')
{
	global $langs;

	if (@file_put_contents(DOL_DATA_ROOT . '/install.lock', '') !== false) {
		setEventMessage($langs->trans('Solved'));
	}

	dolibase_redirect($_SERVER['PHP_SELF']);
}

// Remove install.lock

else if ($action == 'confirm_remove_install_lock' && $confirm == 'yes')
{
	if (file_exists(DOL_DATA_ROOT . '/install.lock')) {
		unlink(DOL_DATA_ROOT . '/install.lock');
	}

	dolibase_redirect($_SERVER['PHP_SELF']);
}

// Set conf.php to writable

else if ($action == 'confirm_chmod_conf_to_writable' && $confirm == 'yes')
{
	global $conffile;

	if (! is_writable(DOL_DOCUMENT_ROOT . '/' . $conffile)) {
		@chmod(DOL_DOCUMENT_ROOT . '/' . $conffile, 0644);
	}

	dolibase_redirect($_SERVER['PHP_SELF']);
}

// Set conf.php to read-only

else if ($action == 'chmod_conf_to_read_only')
{
	global $langs, $conffile;

	if (! @chmod(DOL_DOCUMENT_ROOT . '/' . $conffile, 0444)) {
		setEventMessage($langs->trans('CouldNotSetFilePermissions', DOL_DOCUMENT_ROOT . '/' . $conffile), 'warnings');
	}
	else {
		setEventMessage($langs->trans('Solved'));
	}

	dolibase_redirect($_SERVER['PHP_SELF']);
}

// Enable encrypt database password

else if ($action == 'enable_encryptdbpass')
{
	global $langs, $dolibarr_main_db_pass, $conffile; //, $db;

	$conffileunlocked = @chmod(DOL_DOCUMENT_ROOT . '/' . $conffile, 0644);
	$result = encodedecode_dbpassconf(1);
	if ($result > 0)
	{
		sleep(1); // Don't know why but we need to wait file is completely saved before making the reload. Even with flush and clearstatcache, we need to wait.

		// database value not required
		//dolibarr_set_const($db, "MAIN_DATABASE_PWD_CONFIG_ENCRYPTED", "1");
		if ($conffileunlocked) {
			@chmod(DOL_DOCUMENT_ROOT . '/' . $conffile, 0444);
		}
		dolibase_redirect($_SERVER['PHP_SELF']);
	}
	else
	{
		global $langs, $dolibarr_main_db_pass;

		setEventMessages($langs->trans('InstrucToEncodePass', dol_encode($dolibarr_main_db_pass)), null, 'warnings');
	}
}

// Disable encrypt database password

else if ($action == 'disable_encryptdbpass')
{
	global $langs, $dolibarr_main_db_pass, $conffile; //, $db, $conf;

	$conffileunlocked = @chmod(DOL_DOCUMENT_ROOT . '/' . $conffile, 0644);
	$result = encodedecode_dbpassconf(0);
	if ($result > 0)
	{
		sleep(1); // Don't know why but we need to wait file is completely saved before making the reload. Even with flush and clearstatcache, we need to wait.

		// database value not required
		//dolibarr_del_const($db, "MAIN_DATABASE_PWD_CONFIG_ENCRYPTED", $conf->entity);
		if ($conffileunlocked) {
			@chmod(DOL_DOCUMENT_ROOT . '/' . $conffile, 0444);
		}
		dolibase_redirect($_SERVER['PHP_SELF']);
	}
	else
	{
		setEventMessages($langs->trans('InstrucToClearPass', $dolibarr_main_db_pass), null, 'warnings');
	}
}

// Encrypt users passwords

else if ($action == 'encrypt_pwds')
{
	global $db, $conf;

	dolibarr_set_const($db, "DATABASE_PWD_ENCRYPTED", "1", 'chaine', 0, '', $conf->entity);

	$qb = new QueryBuilder();

	$qb->select('u.rowid, u.pass, u.pass_crypted')
	   ->from('user', 'u')
	   ->where('u.pass IS NOT NULL AND LENGTH(u.pass) < 32'); // Not an MD5 value

	foreach ($qb->result() as $row)
	{
		$hash = dol_hash($row->pass);

		if ($hash) {
			QueryBuilder::getInstance()
			            ->update('user', array('pass_crypted' => $hash, 'pass' => null))
			            ->where('rowid = '.$row->rowid)
			            ->execute();
		}
	}

	dolibase_redirect($_SERVER['PHP_SELF']);
}

// Show confirmation dialog(s)

else if ($action == 'chmod_conf_to_writable' || js_enabled())
{
	$page->askForConfirmation($_SERVER["PHP_SELF"], 'UnsafeAction', 'ConfirmSetConfToWritable', 'confirm_chmod_conf_to_writable', '', 'chmod-conf-to-writable');
}

if ($action == 'remove_install_lock' || js_enabled()) // Note: should be an if not an else if
{
	$page->askForConfirmation($_SERVER["PHP_SELF"], 'UnsafeAction', 'ConfirmRemoveInstallLock', 'confirm_remove_install_lock', '', 'remove-install-lock');
}

// --- End actions

$page->addCssFile('common.css');

$page->addTab('Security', 'securemydolibarr/admin/security.php?mainmenu=home', true);

$page->addTab('AccessControl', 'securemydolibarr/admin/access.php?mainmenu=home');

$page->addTab('Audit', 'securemydolibarr/admin/audit.php?mainmenu=home');

$page->addTab('Backup', 'securemydolibarr/admin/backup.php?mainmenu=home');

$page->addTab('About', 'securemydolibarr/admin/about.php?mainmenu=home');

$page->begin();

$page->addSubtitle('SecurityPrecautions', 'shield.png@securemydolibarr');

$page->showTemplate('precaution.php');

$page->addSubtitle('SecurityIssues', 'security.png@securemydolibarr');

$page->showTemplate('security.php');

$page->end();
